# de4rec


## Framework

[![Framework](https://github.com/fkrasnov2/de4rec/raw/main/de4recv3.png)](https://github.com/fkrasnov2/de4rec)

## Getting Started
bash:
```console
git clone https://github.com/fkrasnov2/de4rec.git
cd de4rec
#to test in isolated env
make install test
```
## Production ready
```bash
pip install de4rec
```

